0.9.9 API documentation: normalize_dot.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
normalize_dot.hpp File Reference

GLM_GTX_normalize_dot More...

Go to the source code of this file.

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | fastNormalizeDot (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Normalize parameters and returns the dot product of x and y. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | normalizeDot (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Normalize parameters and returns the dot product of x and y. More...

## Detailed Description

GLM_GTX_normalize_dot

See also
  Core features (dependence)
  GLM_GTX_fast_square_root (dependence)

Definition in file normalize_dot.hpp.